==> ogre_1.0.1.orig.tar.gz: ogre-free/OgreMain/include/OgreString.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2005 The OGRE Team
Also see acknowledgements in Readme.html

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 59 Temple
Place - Suite 330, Boston, MA 02111-1307, USA, or go to
http://www.gnu.org/copyleft/lesser.txt.
-----------------------------------------------------------------------------
*/
#ifndef _String_H__
#define _String_H__

#include "OgrePrerequisites.h"

// If we're using the GCC 3.1 C++ Std lib
#if defined( GCC_3_1 )

#include <ext/hash_map>
namespace __gnu_cxx
{
    template <> struct hash< Ogre::_StringBase >
    {
        size_t operator()( const Ogre::_StringBase _stringBase ) const 
        { 
            /* This is the PRO-STL way, but it seems to cause problems with VC7.1
               and in some other cases (although I can't recreate it)
            hash<const char*> H;
            return H(_stringBase.c_str());
            */
            /** This is our custom way */
            register size_t ret = 0;
            for( Ogre::_StringBase::const_iterator it = _stringBase.begin(); it != _stringBase.end(); ++it )
                ret = 5 * ret + *it;

            return ret;
        }
    };
}

// If we're using plain vanilla VC7 Std lib
#elif !defined( _STLP_HASH_FUN_H )

#	if _DEFINE_DEPRECATED_HASH_CLASSES
namespace std 
#	else
namespace stdext
#	endif
{
    template<> size_t hash_compare< Ogre::_StringBase, std::less< Ogre::_StringBase > >::operator ()( const Ogre::_StringBase& _stringBase ) const
    {
        /* This is the PRO-STL way, but it seems to cause problems with VC7.1
            and in some other cases (although I can't recreate it)
        hash<const char*> H;
        return H(_stringBase.c_str());
        */
        /** This is our custom way */
        register size_t ret = 0;
        for( Ogre::_StringBase::const_iterator it = _stringBase.begin(); it != _stringBase.end(); ++it )
            ret = 5 * ret + *it;

        return ret;
    }
}

#endif

namespace Ogre {

    /** Utility class for manipulating Strings.  */
    class _OgreExport StringUtil
    {
	public:
        typedef std::stringstream StrStreamType;

        /** Removes any whitespace characters, be it standard space or
            TABs and so on.
            @remarks
                The user may specify wether they want to trim only the
                beginning or the end of the String ( the default action is
                to trim both).
        */
        static void trim( String& str, bool left = true, bool right = true );

        /** Returns a StringVector that contains all the substrings delimited
            by the characters in the passed <code>delims</code> argument.
            @param 
                delims A list of delimiter characters to split by
            @param 
                maxSplits The maximum number of splits to perform (0 for unlimited splits). If this
                parameters is > 0, the splitting process will stop after this many splits, left to right.
        */
		static std::vector< String > split( const String& str, const String& delims = "\t\n ", unsigned int maxSplits = 0);

        /** Upper-cases all the characters in the string.
        */
        static void toLowerCase( String& str );

        /** Lower-cases all the characters in the string.
        */
        static void toUpperCase( String& str );

        /** Converts the contents of the string to a Real.
        @remarks
            Assumes the only contents of the string are a valid parsable Real. Defaults to  a
            value of 0.0 if conversion is not possible.
        */
        static Real toReal( const String& str );

        /** Returns whether the string begins with the pattern passed in.
        @param pattern The pattern to compare with.
        @param lowerCase If true, the end of the string will be lower cased before 
            comparison, pattern should also be in lower case.
        */
        static bool startsWith(const String& str, const String& pattern, bool lowerCase = true);

        /** Returns whether the string ends with the pattern passed in.
        @param pattern The pattern to compare with.
        @param lowerCase If true, the end of the string will be lower cased before 
            comparison, pattern should also be in lower case.
        */
        static bool endsWith(const String& str, const String& pattern, bool lowerCase = true);

        /** Method for standardising paths - use forward slashes only, end with slash. 
        */
        static String standardisePath( const String &init);

        /** Method for splitting a fully qualified filename into the base name 
            and path. 
        @remarks
            Path is standardised as in standardisePath
        */
        static void splitFilename(const String& qualifiedName, 
            String& outBasename, String& outPath);

        /** Simple pattern-matching routine allowing a wildcard pattern. 
        @param str String to test
        @param pattern Pattern to match against; can include simple '*' wildcards
        @param caseSensitive Whether the match is case sensitive or not
        */
        static bool match(const String& str, const String& pattern, bool caseSensitive = true);
            




        /// Constant blank string, useful for returning by ref where local does not exist
        static const String BLANK;
    };


#ifdef GCC_3_1
    typedef ::__gnu_cxx::hash< _StringBase > _StringHash;    
#elif !defined( _STLP_HASH_FUN_H )
#	if _DEFINE_DEPRECATED_HASH_CLASSES
		typedef std::hash_compare< _StringBase, std::less< _StringBase > > _StringHash;
#	else
		typedef stdext::hash_compare< _StringBase, std::less< _StringBase > > _StringHash;
#	endif
#else
    typedef std::hash< _StringBase > _StringHash;
#endif

} // namespace Ogre

#endif // _String_H__

==> ogre_1.0.6.orig.tar.gz: ogre-free/OgreMain/include/OgreString.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2005 The OGRE Team
Also see acknowledgements in Readme.html

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 59 Temple
Place - Suite 330, Boston, MA 02111-1307, USA, or go to
http://www.gnu.org/copyleft/lesser.txt.
-----------------------------------------------------------------------------
*/
#ifndef _String_H__
#define _String_H__

#include "OgrePrerequisites.h"

// If we're using the GCC 3.1 C++ Std lib
#if OGRE_COMPILER == OGRE_COMPILER_GNUC && OGRE_COMP_VER >= 310

#include <ext/hash_map>
namespace __gnu_cxx
{
    template <> struct hash< Ogre::_StringBase >
    {
        size_t operator()( const Ogre::_StringBase _stringBase ) const 
        { 
            /* This is the PRO-STL way, but it seems to cause problems with VC7.1
               and in some other cases (although I can't recreate it)
            hash<const char*> H;
            return H(_stringBase.c_str());
            */
            /** This is our custom way */
            register size_t ret = 0;
            for( Ogre::_StringBase::const_iterator it = _stringBase.begin(); it != _stringBase.end(); ++it )
                ret = 5 * ret + *it;

            return ret;
        }
    };
}

// If we're using plain vanilla VC7 Std lib
#elif !defined( _STLP_HASH_FUN_H )

#	if _DEFINE_DEPRECATED_HASH_CLASSES
namespace std 
#	else
namespace stdext
#	endif
{
    template<> size_t hash_compare< Ogre::_StringBase, std::less< Ogre::_StringBase > >::operator ()( const Ogre::_StringBase& _stringBase ) const
    {
        /* This is the PRO-STL way, but it seems to cause problems with VC7.1
            and in some other cases (although I can't recreate it)
        hash<const char*> H;
        return H(_stringBase.c_str());
        */
        /** This is our custom way */
        register size_t ret = 0;
        for( Ogre::_StringBase::const_iterator it = _stringBase.begin(); it != _stringBase.end(); ++it )
            ret = 5 * ret + *it;

        return ret;
    }
}

#endif

namespace Ogre {

    /** Utility class for manipulating Strings.  */
    class _OgreExport StringUtil
    {
	public:
        typedef std::stringstream StrStreamType;

        /** Removes any whitespace characters, be it standard space or
            TABs and so on.
            @remarks
                The user may specify wether they want to trim only the
                beginning or the end of the String ( the default action is
                to trim both).
        */
        static void trim( String& str, bool left = true, bool right = true );

        /** Returns a StringVector that contains all the substrings delimited
            by the characters in the passed <code>delims</code> argument.
            @param 
                delims A list of delimiter characters to split by
            @param 
                maxSplits The maximum number of splits to perform (0 for unlimited splits). If this
                parameters is > 0, the splitting process will stop after this many splits, left to right.
        */
		static std::vector< String > split( const String& str, const String& delims = "\t\n ", unsigned int maxSplits = 0);

        /** Upper-cases all the characters in the string.
        */
        static void toLowerCase( String& str );

        /** Lower-cases all the characters in the string.
        */
        static void toUpperCase( String& str );

        /** Converts the contents of the string to a Real.
        @remarks
            Assumes the only contents of the string are a valid parsable Real. Defaults to  a
            value of 0.0 if conversion is not possible.
        */
        static Real toReal( const String& str );

        /** Returns whether the string begins with the pattern passed in.
        @param pattern The pattern to compare with.
        @param lowerCase If true, the end of the string will be lower cased before 
            comparison, pattern should also be in lower case.
        */
        static bool startsWith(const String& str, const String& pattern, bool lowerCase = true);

        /** Returns whether the string ends with the pattern passed in.
        @param pattern The pattern to compare with.
        @param lowerCase If true, the end of the string will be lower cased before 
            comparison, pattern should also be in lower case.
        */
        static bool endsWith(const String& str, const String& pattern, bool lowerCase = true);

        /** Method for standardising paths - use forward slashes only, end with slash. 
        */
        static String standardisePath( const String &init);

        /** Method for splitting a fully qualified filename into the base name 
            and path. 
        @remarks
            Path is standardised as in standardisePath
        */
        static void splitFilename(const String& qualifiedName, 
            String& outBasename, String& outPath);

        /** Simple pattern-matching routine allowing a wildcard pattern. 
        @param str String to test
        @param pattern Pattern to match against; can include simple '*' wildcards
        @param caseSensitive Whether the match is case sensitive or not
        */
        static bool match(const String& str, const String& pattern, bool caseSensitive = true);
            




        /// Constant blank string, useful for returning by ref where local does not exist
        static const String BLANK;
    };


#if OGRE_COMPILER == OGRE_COMPILER_GNUC && OGRE_COMP_VER >= 310
    typedef ::__gnu_cxx::hash< _StringBase > _StringHash;    
#elif !defined( _STLP_HASH_FUN_H )
#	if _DEFINE_DEPRECATED_HASH_CLASSES
		typedef std::hash_compare< _StringBase, std::less< _StringBase > > _StringHash;
#	else
		typedef stdext::hash_compare< _StringBase, std::less< _StringBase > > _StringHash;
#	endif
#else
    typedef std::hash< _StringBase > _StringHash;
#endif

} // namespace Ogre

#endif // _String_H__
